summaryrefslogtreecommitdiffstats
path: root/content/browser/tab_contents/tab_contents_delegate.h
diff options
context:
space:
mode:
authorjianli@chromium.org <jianli@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-05-05 20:35:14 +0000
committerjianli@chromium.org <jianli@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-05-05 20:35:14 +0000
commitb35b26b360b5d84d064d63440590902d4974b59d (patch)
treef0aa8b0b32ca80ad7eb5efc1f78a5dcd45899b13 /content/browser/tab_contents/tab_contents_delegate.h
parent4d9160ff743804acf89a5a50a0b43c113aecc1ab (diff)
downloadchromium_src-b35b26b360b5d84d064d63440590902d4974b59d.zip
chromium_src-b35b26b360b5d84d064d63440590902d4974b59d.tar.gz
chromium_src-b35b26b360b5d84d064d63440590902d4974b59d.tar.bz2
Browser::Type cleanup.
BUG=None TEST=Existing tests R=ben@chromium.org,stevenjb@chromium.org,phajdan.jr@chromium.org Review URL: http://codereview.chromium.org/6697032 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@84303 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'content/browser/tab_contents/tab_contents_delegate.h')
-rw-r--r--content/browser/tab_contents/tab_contents_delegate.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/content/browser/tab_contents/tab_contents_delegate.h b/content/browser/tab_contents/tab_contents_delegate.h
index f79a277..2c3bdbb 100644
--- a/content/browser/tab_contents/tab_contents_delegate.h
+++ b/content/browser/tab_contents/tab_contents_delegate.h
@@ -103,8 +103,9 @@ class TabContentsDelegate {
// caller, and it is safe to call "source->set_delegate(someone_else);".
virtual void DetachContents(TabContents* source);
- // Called to determine if the TabContents is contained in a popup window.
- virtual bool IsPopup(const TabContents* source) const;
+ // Called to determine if the TabContents is contained in a popup window
+ // or a panel window.
+ virtual bool IsPopupOrPanel(const TabContents* source) const;
// If |source| is constrained, returns the tab containing it. Otherwise
// returns |source|. TODO(avi): Remove in favor of GetConstrainingContents on